==> plantuml-libs-5.2.0.tgz: package/distribution/aws-20210730/Resource/MachineLearning/AmazonRekognitionVideo.md <==
# AmazonRekognitionVideo


```text
aws-20210730/Resource/MachineLearning/AmazonRekognitionVideo
```

```text
include('aws-20210730/Resource/MachineLearning/AmazonRekognitionVideo')
```



| Illustration | AmazonRekognitionVideo | AmazonRekognitionVideoCard | AmazonRekognitionVideoGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/MachineLearning/AmazonRekognitionVideo.png) | ![illustration for AmazonRekognitionVideo](../../../aws-20210730/Resource/MachineLearning/AmazonRekognitionVideo.Local.png) | ![illustration for AmazonRekognitionVideoCard](../../../aws-20210730/Resource/MachineLearning/AmazonRekognitionVideoCard.Local.png) | ![illustration for AmazonRekognitionVideoGroup](../../../aws-20210730/Resource/MachineLearning/AmazonRekognitionVideoGroup.Local.png) |




## AmazonRekognitionVideo

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonRekognitionVideo
include('aws-20210730/Resource/MachineLearning/AmazonRekognitionVideo')

' renders the element
AmazonRekognitionVideo('AmazonRekognitionVideo', 'Amazon Rekognition Video', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonRekognitionVideo
include('aws-20210730/Resource/MachineLearning/AmazonRekognitionVideo')

' renders the element
AmazonRekognitionVideo('AmazonRekognitionVideo', 'Amazon Rekognition Video', 'an optional tech label')
@enduml
```

## AmazonRekognitionVideoCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonRekognitionVideoCard
include('aws-20210730/Resource/MachineLearning/AmazonRekognitionVideo')

' renders the element
AmazonRekognitionVideoCard('AmazonRekognitionVideoCard', 'Amazon Rekognition Video Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonRekognitionVideoCard
include('aws-20210730/Resource/MachineLearning/AmazonRekognitionVideo')

' renders the element
AmazonRekognitionVideoCard('AmazonRekognitionVideoCard', 'Amazon Rekognition Video Card', 'an optional description')
@enduml
```

## AmazonRekognitionVideoGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonRekognitionVideoGroup
include('aws-20210730/Resource/MachineLearning/AmazonRekognitionVideo')

' renders the element
AmazonRekognitionVideoGroup('AmazonRekognitionVideoGroup', 'Amazon Rekognition Video Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonRekognitionVideoGroup
include('aws-20210730/Resource/MachineLearning/AmazonRekognitionVideo')

' renders the element
AmazonRekognitionVideoGroup('AmazonRekognitionVideoGroup', 'Amazon Rekognition Video Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.3.0.tgz: package/distribution/aws-20210730/Resource/MachineLearning/AmazonRekognitionVideo.md <==
# AmazonRekognitionVideo


```text
aws-20210730/Resource/MachineLearning/AmazonRekognitionVideo
```

```text
include('aws-20210730/Resource/MachineLearning/AmazonRekognitionVideo')
```



| Illustration | AmazonRekognitionVideo | AmazonRekognitionVideoCard | AmazonRekognitionVideoGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../aws-20210730/Resource/MachineLearning/AmazonRekognitionVideo.png) | ![illustration for AmazonRekognitionVideo](../../../aws-20210730/Resource/MachineLearning/AmazonRekognitionVideo.Local.png) | ![illustration for AmazonRekognitionVideoCard](../../../aws-20210730/Resource/MachineLearning/AmazonRekognitionVideoCard.Local.png) | ![illustration for AmazonRekognitionVideoGroup](../../../aws-20210730/Resource/MachineLearning/AmazonRekognitionVideoGroup.Local.png) |




## AmazonRekognitionVideo

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonRekognitionVideo
include('aws-20210730/Resource/MachineLearning/AmazonRekognitionVideo')

' renders the element
AmazonRekognitionVideo('AmazonRekognitionVideo', 'Amazon Rekognition Video', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonRekognitionVideo
include('aws-20210730/Resource/MachineLearning/AmazonRekognitionVideo')

' renders the element
AmazonRekognitionVideo('AmazonRekognitionVideo', 'Amazon Rekognition Video', 'an optional tech label')
@enduml
```

## AmazonRekognitionVideoCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonRekognitionVideoCard
include('aws-20210730/Resource/MachineLearning/AmazonRekognitionVideo')

' renders the element
AmazonRekognitionVideoCard('AmazonRekognitionVideoCard', 'Amazon Rekognition Video Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonRekognitionVideoCard
include('aws-20210730/Resource/MachineLearning/AmazonRekognitionVideo')

' renders the element
AmazonRekognitionVideoCard('AmazonRekognitionVideoCard', 'Amazon Rekognition Video Card', 'an optional description')
@enduml
```

## AmazonRekognitionVideoGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonRekognitionVideoGroup
include('aws-20210730/Resource/MachineLearning/AmazonRekognitionVideo')

' renders the element
AmazonRekognitionVideoGroup('AmazonRekognitionVideoGroup', 'Amazon Rekognition Video Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('aws-20210730/bootstrap')

' loads the Item which embeds the element AmazonRekognitionVideoGroup
include('aws-20210730/Resource/MachineLearning/AmazonRekognitionVideo')

' renders the element
AmazonRekognitionVideoGroup('AmazonRekognitionVideoGroup', 'Amazon Rekognition Video Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
